import threading
import time


class SystemStats(object):

    samples: int = 0

    def __init__(self, sample_rate: float = 0.2):
        self._thread = threading.Thread(target=self._monitor)
        self.sample_rate = sample_rate

    def start(self):
        self._thread.start()

    def _monitor(self):
        while True:
            self.samples += 1
            time.sleep(self.sample_rate)

    def stats(self):
        return {}



from setuptools import setup

with open('README.md', 'r', encoding='utf-8') as fp:
    long_description = fp.read()

requirements = [
    'Click>=7.0.0'
]

setup(
    name='datatorch',
    version='0.0.1',
    description='A CLI and library for interacting with DataTorch',
    author='DataTorch',
    author_email='support@datatorch.io',
    entry_points={
        'console_scripts': [
            'datatorch=datatorch.cli:main',
            'dt=datatorch.cli:main'
        ]
    },
    url='https://github.com/datatorch/python',
    packages=['datatorch'],
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requirements=requirements,
    python_requires='>=3.6',
    license='MIT license',
    zip_safe=False
)



from logging import Logger, LoggerAdapter


class PrefixLogger(LoggerAdapter):
    """ A logger adapter that adds a prefix to every message """

    def __init__(self, logger: Logger, prefix: str):
        super(LoggerAdapter, self).__init__()
        self.logger = logger
        self.prefix = prefix

    def process(self, msg: str, kwargs: dict) -> (str, dict):
        return (f'[{self.prefix}] ' + msg, kwargs)
